sequencetools.partition_sequence_cyclically_by_weights_at_least_with_overhang
=============================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_cyclically_by_weights_at_least_with_overhang
